@@ -12,7 +12,7 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import mock
+from unittest import mock
 import zipfile
 
 from osc_lib.tests import utils as osc_tests_utils
